summaryrefslogtreecommitdiffstats
path: root/tqtinterface/qt4/src/network
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-08-09 22:25:47 -0500
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-08-09 22:25:47 -0500
commiteaa7ee2e0bbca40ba3173c4304f81957e8964291 (patch)
tree4f793aa48a5080aedc94ce6e519c3b86708f2b88 /tqtinterface/qt4/src/network
parent79a9d7a46a20d4a0923bc06fc471fdc2176ef865 (diff)
downloadexperimental-eaa7ee2e0bbca40ba3173c4304f81957e8964291.tar.gz
experimental-eaa7ee2e0bbca40ba3173c4304f81957e8964291.zip
rename the following methods:
tqfind find tqreplace replace tqcontains contains
Diffstat (limited to 'tqtinterface/qt4/src/network')
-rw-r--r--tqtinterface/qt4/src/network/tqdns.cpp68
-rw-r--r--tqtinterface/qt4/src/network/tqdns.h2
-rw-r--r--tqtinterface/qt4/src/network/tqftp.cpp12
-rw-r--r--tqtinterface/qt4/src/network/tqhostaddress.cpp4
-rw-r--r--tqtinterface/qt4/src/network/tqhttp.cpp28
-rw-r--r--tqtinterface/qt4/src/network/tqsocket.cpp18
-rw-r--r--tqtinterface/qt4/src/network/tqsocketdevice_unix.cpp2
7 files changed, 67 insertions, 67 deletions
diff --git a/tqtinterface/qt4/src/network/tqdns.h b/tqtinterface/qt4/src/network/tqdns.h
index 14a5e65..23c84ee 100644
--- a/tqtinterface/qt4/src/network/tqdns.h
+++ b/tqtinterface/qt4/src/network/tqdns.h
@@ -364,7 +364,7 @@ private:
class TQDnsSocket: public TQObject {
Q_OBJECT
TQ_OBJECT
- // note: Private not public. This class tqcontains NO public API.
+ // note: Private not public. This class contains NO public API.
protected:
TQDnsSocket( TQObject *, const char * );
virtual ~TQDnsSocket();
diff --git a/tqtinterface/qt4/src/network/tqftp.cpp b/tqtinterface/qt4/src/network/tqftp.cpp
index 7fb239e..7b6acdd 100644
--- a/tqtinterface/qt4/src/network/tqftp.cpp
+++ b/tqtinterface/qt4/src/network/tqftp.cpp
@@ -481,7 +481,7 @@ bool TQFtpDTP::parseDir( const TQString &buffer, const TQString &userName, TQUrl
dateStr += lst[ 6 ];
dateStr += ' ';
- if ( lst[ 7 ].tqcontains( ":" ) ) {
+ if ( lst[ 7 ].contains( ":" ) ) {
time = TQTime( lst[ 7 ].left( 2 ).toInt(), lst[ 7 ].right( 2 ).toInt() );
dateStr += TQString::number( TQDate::currentDate().year() );
} else {
@@ -491,7 +491,7 @@ bool TQFtpDTP::parseDir( const TQString &buffer, const TQString &userName, TQUrl
TQDate date = TQT_TQDATE_OBJECT(TQDate::fromString( dateStr ));
info->setLastModified( TQDateTime( date, time ) );
- if ( lst[ 7 ].tqcontains( ":" ) ) {
+ if ( lst[ 7 ].contains( ":" ) ) {
const int futureTolerance = 600;
if( info->lastModified().secsTo( TQDateTime::tqcurrentDateTime() ) < -futureTolerance ) {
TQDateTime dt = info->lastModified();
@@ -1046,10 +1046,10 @@ static TQFtpPrivate* d( const TQFtp* foo )
d_ptr->setAutoDelete( TRUE );
qAddPostRoutine( cleanup_d_ptr );
}
- TQFtpPrivate* ret = d_ptr->tqfind( (void*)foo );
+ TQFtpPrivate* ret = d_ptr->find( (void*)foo );
if ( ! ret ) {
ret = new TQFtpPrivate;
- d_ptr->tqreplace( (void*) foo, ret );
+ d_ptr->replace( (void*) foo, ret );
}
return ret;
}
@@ -1347,7 +1347,7 @@ void TQFtp::init()
\fn void TQFtp::listInfo( const TQUrlInfo &i );
This signal is emitted for each directory entry the list() command
- tqfinds. The details of the entry are stored in \a i.
+ finds. The details of the entry are stored in \a i.
\sa list()
*/
@@ -1929,7 +1929,7 @@ TQFtp::State TQFtp::state() const
}
/*!
- Returns the last error that occurred. This is useful to tqfind out
+ Returns the last error that occurred. This is useful to find out
what when wrong when receiving a commandFinished() or a done()
signal with the \c error argument set to \c TRUE.
diff --git a/tqtinterface/qt4/src/network/tqhttp.cpp b/tqtinterface/qt4/src/network/tqhttp.cpp
index 7d324ea..53cdbeb 100644
--- a/tqtinterface/qt4/src/network/tqhttp.cpp
+++ b/tqtinterface/qt4/src/network/tqhttp.cpp
@@ -333,7 +333,7 @@ void TQHttpCloseRequest::start( TQHttp *http )
/*!
\class TQHttpHeader tqhttp.h
- \brief The TQHttpHeader class tqcontains header information for HTTP.
+ \brief The TQHttpHeader class contains header information for HTTP.
\if defined(commercial)
It is part of the <a href="commercialeditions.html">TQt Enterprise Edition</a>.
\endif
@@ -445,7 +445,7 @@ bool TQHttpHeader::isValid() const
/*! \internal
Parses the HTTP header string \a str for header fields and adds
- the keys/values it tqfinds. If the string is not parsed successfully
+ the keys/values it finds. If the string is not parsed successfully
the TQHttpHeader becomes \link isValid() invalid\endlink.
Returns TRUE if \a str was successfully parsed; otherwise returns FALSE.
@@ -455,7 +455,7 @@ bool TQHttpHeader::isValid() const
bool TQHttpHeader::parse( const TQString& str )
{
TQStringList lst;
- int pos = str.tqfind( '\n' );
+ int pos = str.find( '\n' );
if ( pos > 0 && str.at( pos - 1 ) == '\r' )
lst = TQStringList::split( "\r\n", str.stripWhiteSpace(), FALSE );
else
@@ -526,7 +526,7 @@ TQStringList TQHttpHeader::keys() const
*/
bool TQHttpHeader::hasKey( const TQString& key ) const
{
- return values.tqcontains( key.lower() );
+ return values.contains( key.lower() );
}
/*!
@@ -534,7 +534,7 @@ bool TQHttpHeader::hasKey( const TQString& key ) const
If no entry with \a key exists, a new entry with the given \a key
and \a value is created. If an entry with the \a key already
- exists, its value is discarded and tqreplaced with the given \a
+ exists, its value is discarded and replaced with the given \a
value.
\sa value() hasKey() removeValue()
@@ -564,7 +564,7 @@ void TQHttpHeader::removeValue( const TQString& key )
*/
bool TQHttpHeader::parseLine( const TQString& line, int )
{
- int i = line.tqfind( ":" );
+ int i = line.find( ":" );
if ( i == -1 )
return FALSE;
@@ -649,7 +649,7 @@ TQString TQHttpHeader::contentType() const
if ( type.isEmpty() )
return TQString::null;
- int pos = type.tqfind( ";" );
+ int pos = type.find( ";" );
if ( pos == -1 )
return type;
@@ -675,7 +675,7 @@ void TQHttpHeader::setContentType( const TQString& type )
/*!
\class TQHttpResponseHeader tqhttp.h
- \brief The TQHttpResponseHeader class tqcontains response header information for HTTP.
+ \brief The TQHttpResponseHeader class contains response header information for HTTP.
\if defined(commercial)
It is part of the <a href="commercialeditions.html">TQt Enterprise Edition</a>.
\endif
@@ -807,7 +807,7 @@ bool TQHttpResponseHeader::parseLine( const TQString& line, int number )
majVer = l[5].latin1() - '0';
minVer = l[7].latin1() - '0';
- int pos = l.tqfind( ' ', 9 );
+ int pos = l.find( ' ', 9 );
if ( pos != -1 ) {
reasonPhr = l.mid( pos + 1 );
statCode = l.mid( 9, pos - 9 ).toInt();
@@ -838,7 +838,7 @@ TQString TQHttpResponseHeader::toString() const
/*!
\class TQHttpRequestHeader tqhttp.h
- \brief The TQHttpRequestHeader class tqcontains request header information for
+ \brief The TQHttpRequestHeader class contains request header information for
\if defined(commercial)
It is part of the <a href="commercialeditions.html">TQt Enterprise Edition</a>.
\endif
@@ -1166,7 +1166,7 @@ TQString TQHttpRequestHeader::toString() const
You can then get details about the error with the error() and
errorString() functions. Note that only unexpected behaviour, like
network failure is considered as an error. If the server response
- tqcontains an error status, like a 404 response, this is reported as
+ contains an error status, like a 404 response, this is reported as
a normal response case. So you should always check the \link
TQHttpResponseHeader::statusCode() status code \endlink of the
response header.
@@ -1985,7 +1985,7 @@ void TQHttp::slotReadyRead()
if (d->response.statusCode() != 100) {
d->readHeader = FALSE;
if ( d->response.hasKey( "transfer-encoding" ) &&
- d->response.value( "transfer-encoding" ).lower().tqcontains( "chunked" ) )
+ d->response.value( "transfer-encoding" ).lower().contains( "chunked" ) )
d->chunkedSize = 0;
emit responseHeaderReceived( d->response );
@@ -2008,7 +2008,7 @@ void TQHttp::slotReadyRead()
if ( !d->socket.canReadLine() )
break;
TQString sizeString = d->socket.readLine();
- int tPos = sizeString.tqfind( ';' );
+ int tPos = sizeString.find( ';' );
if ( tPos != -1 )
sizeString.truncate( tPos );
bool ok;
@@ -2135,7 +2135,7 @@ TQHttp::State TQHttp::state() const
}
/*!
- Returns the last error that occurred. This is useful to tqfind out
+ Returns the last error that occurred. This is useful to find out
what happened when receiving a requestFinished() or a done()
signal with the \c error argument \c TRUE.
diff --git a/tqtinterface/qt4/src/network/tqsocketdevice_unix.cpp b/tqtinterface/qt4/src/network/tqsocketdevice_unix.cpp
index a0bf65d..46c3932 100644
--- a/tqtinterface/qt4/src/network/tqsocketdevice_unix.cpp
+++ b/tqtinterface/qt4/src/network/tqsocketdevice_unix.cpp
@@ -879,7 +879,7 @@ TQ_LONG TQSocketDevice::bytesAvailable() const
If \a timeout is non-null and no error occurred (i.e. it does not
return -1): this function sets \a *timeout to TRUE, if the reason
for returning was that the timeout was reached; otherwise it sets
- \a *timeout to FALSE. This is useful to tqfind out if the peer
+ \a *timeout to FALSE. This is useful to find out if the peer
closed the connection.
\warning This is a blocking call and should be avoided in event
diff --git a/tqtinterface/qt4/src/network/tqdns.cpp b/tqtinterface/qt4/src/network/tqdns.cpp
index 24b5401..898ac43 100644
--- a/tqtinterface/qt4/src/network/tqdns.cpp
+++ b/tqtinterface/qt4/src/network/tqdns.cpp
@@ -762,7 +762,7 @@ void TQDnsAnswer::parse()
if ( rr->target.length() && rr->deleteTime > 0 && rr->current )
used.insert( rr->target, (void*)42 );
if ( ( rr->t == TQDns::A || rr->t == TQDns::Aaaa ) &&
- used.tqfind( rr->domain->name() ) != 0 )
+ used.find( rr->domain->name() ) != 0 )
rr->deleteTime = rr->expireTime;
}
@@ -829,7 +829,7 @@ void TQDnsAnswer::notify()
it.toFirst();
while( (dns=(TQDns*)(it.current())) != 0 ) {
++it;
- if ( notified.tqfind( (void*)dns ) == 0 ) {
+ if ( notified.find( (void*)dns ) == 0 ) {
notified.insert( (void*)dns, (void*)42 );
if ( rrs->count() == 0 ) {
#if defined(TQDNS_DEBUG)
@@ -839,7 +839,7 @@ void TQDnsAnswer::notify()
((TQDnsUgleHack*)dns)->ugle( true );
} else {
TQStringList n = dns->qualifiedNames();
- if ( query && n.tqcontains(query->l) )
+ if ( query && n.contains(query->l) )
((TQDnsUgleHack*)dns)->ugle();
#if defined(TQDNS_DEBUG)
else
@@ -1189,7 +1189,7 @@ void TQDnsManager::transmitQuery( int i )
int pp = 12;
uint lp = 0;
while( lp < (uint) q->l.length() ) {
- int le = q->l.tqfind( QLatin1Char('.'), lp );
+ int le = q->l.find( QLatin1Char('.'), lp );
if ( le < 0 )
le = q->l.length();
TQString component = q->l.mid( lp, le-lp );
@@ -1241,7 +1241,7 @@ void TQDnsManager::transmitQuery( int i )
TQDns::doResInit();
if ( !theNs || theNs->isEmpty() ) {
// we don't tqfind any name servers. We fake an NXDomain
// with a very short life time...
TQDnsAnswer answer( q );
answer.notify();
@@ -1297,7 +1297,7 @@ void TQDnsManager::transmitQuery( int i )
TQDnsDomain * TQDnsManager::domain( const TQString & label )
{
- TQDnsDomain * d = cache.tqfind( label );
+ TQDnsDomain * d = cache.find( label );
if ( !d ) {
d = new TQDnsDomain( label );
cache.insert( label, d );
@@ -1495,21 +1495,21 @@ TQPtrList<TQDnsRR> * TQDnsDomain::cached( const TQDns * r )
// we haven't done it before, so maybe we should. but
// wait - if it's an unqualified name, only ask when all
// the other alternatives are exhausted.
- if ( q == m->queries.size() && ( s.tqfind( QLatin1Char('.') ) >= 0 ||
+ if ( q == m->queries.size() && ( s.find( QLatin1Char('.') ) >= 0 ||
int(l->count()) >= n.count()-1 ) ) {
TQDnsQuery * query = new TQDnsQuery;
query->started = now();
query->id = ++theId;
query->t = r->recordType();
query->l = s;
- query->dns->tqreplace( (void*)r, (void*)r );
+ query->dns->replace( (void*)r, (void*)r );
TQT_BASE_OBJECT_NAME::connect( query, TQT_SIGNAL(timeout()),
TQDnsManager::manager(), TQT_SLOT(retransmit()) );
TQDnsManager::manager()->transmitQuery( query );
} else if ( q < m->queries.size() ) {
// if we've found an earlier query for the same
// domain/type, subscribe to its answer
- m->queries[q]->dns->tqreplace( (void*)r, (void*)r );
+ m->queries[q]->dns->replace( (void*)r, (void*)r );
}
}
}
@@ -1822,7 +1822,7 @@ void TQDns::setLabel( const TQHostAddress & address )
\value Mx Mail eXchanger names. Used for mail delivery.
- \value Srv SeRVer names. Generic record type for tqfinding
+ \value Srv SeRVer names. Generic record type for finding
servers. So far mostly unused.
\value Cname Canonical names. Maps from nicknames to the true
@@ -2021,7 +2021,7 @@ TQValueList<TQHostAddress> TQDns::addresses() const
/*!
Returns a list of mail servers if the record type is \c Mx. The
- class TQDns::MailServer tqcontains the following public variables:
+ class TQDns::MailServer contains the following public variables:
\list
\i TQString TQDns::MailServer::name
\i Q_UINT16 TQDns::MailServer::priority
@@ -2065,7 +2065,7 @@ TQValueList<TQDns::MailServer> TQDns::mailServers() const
/*!
Returns a list of servers if the record type is \c Srv. The class
- TQDns::Server tqcontains the following public variables:
+ TQDns::Server contains the following public variables:
\list
\i TQString TQDns::Server::name
\i Q_UINT16 TQDns::Server::priority
@@ -2359,7 +2359,7 @@ void TQDns::doResInit()
if ( !nameServer.isEmpty() ) {
first = 0;
do {
- last = nameServer.tqfind( QLatin1Char(separator), first );
+ last = nameServer.find( QLatin1Char(separator), first );
if ( last < 0 )
last = nameServer.length();
TQDns tmp( nameServer.mid( first, last-first ), TQDns::A );
@@ -2375,7 +2375,7 @@ void TQDns::doResInit()
searchList = searchList.simplifyWhiteSpace().lower();
first = 0;
do {
- last = searchList.tqfind( QLatin1Char(separator), first );
+ last = searchList.find( QLatin1Char(separator), first );
if ( last < 0 )
last = searchList.length();
theDomains->append( qstrdup( searchList.mid( first, last-first ).latin1() ) );
@@ -2496,7 +2496,7 @@ void TQDns::doResInit()
struct __res_state res;
res_ninit( &res );
int i;
// tqfind the name servers to use
for( i=0; i < MAXNS && i < res.nscount; i++ )
theNs->append( new TQHostAddress( ntohl( res.nsaddr_list[i].sin_addr.s_addr ) ) );
# if defined(MAXDFLSRCH)
@@ -2512,7 +2512,7 @@ void TQDns::doResInit()
#else
res_init();
int i;
// tqfind the name servers to use
for( i=0; i < MAXNS && i < _res.nscount; i++ )
theNs->append( new TQHostAddress( ntohl( _res.nsaddr_list[i].sin_addr.s_addr ) ) );
# if defined(MAXDFLSRCH)
@@ -2541,7 +2541,7 @@ void TQDns::doResInit()
QFile hosts( TQString::fromLatin1( "/etc/hosts" ) );
if ( hosts.open( QIODevice::ReadOnly ) ) {
// read the /etc/hosts file, creating long-life A and PTR RRs
// for the things we tqfind.
QTextStream i( &hosts );
TQString line;
while( !i.atEnd() ) {
@@ -3365,7 +3365,7 @@ void TQDnsAnswer::parse()
if ( rr->target.length() && rr->deleteTime > 0 && rr->current )
used.insert( rr->target, (void*)42 );
if ( ( rr->t == TQDns::A || rr->t == TQDns::Aaaa ) &&
- used.tqfind( rr->domain->name() ) != 0 )
+ used.find( rr->domain->name() ) != 0 )
rr->deleteTime = rr->expireTime;
}
@@ -3432,7 +3432,7 @@ void TQDnsAnswer::notify()
it.toFirst();
while( (dns=(TQDns*)(it.current())) != 0 ) {
++it;
- if ( notified.tqfind( (void*)dns ) == 0 ) {
+ if ( notified.find( (void*)dns ) == 0 ) {
notified.insert( (void*)dns, (void*)42 );
if ( rrs->count() == 0 ) {
#if defined(TQDNS_DEBUG)
@@ -3442,7 +3442,7 @@ void TQDnsAnswer::notify()
((TQDnsUgleHack*)dns)->ugle( TRUE );
} else {
TQStringList n = dns->qualifiedNames();
- if ( query && n.tqcontains(query->l) )
+ if ( query && n.contains(query->l) )
((TQDnsUgleHack*)dns)->ugle();
#if defined(TQDNS_DEBUG)
else
@@ -3796,7 +3796,7 @@ void TQDnsManager::transmitQuery( int i )
int pp = 12;
uint lp = 0;
while( lp < q->l.length() ) {
- int le = q->l.tqfind( '.', lp );
+ int le = q->l.find( '.', lp );
if ( le < 0 )
le = q->l.length();
TQString component = q->l.mid( lp, le-lp );
@@ -3848,7 +3848,7 @@ void TQDnsManager::transmitQuery( int i )
TQDns::doResInit();
if ( !ns || ns->isEmpty() ) {
// we don't tqfind any name servers. We fake an NXDomain
// with a very short life time...
TQDnsAnswer answer( q );
answer.notify();
@@ -3904,7 +3904,7 @@ void TQDnsManager::transmitQuery( int i )
TQDnsDomain * TQDnsManager::domain( const TQString & label )
{
- TQDnsDomain * d = cache.tqfind( label );
+ TQDnsDomain * d = cache.find( label );
if ( !d ) {
d = new TQDnsDomain( label );
cache.insert( label, d );
@@ -4104,21 +4104,21 @@ TQPtrList<TQDnsRR> * TQDnsDomain::cached( const TQDns * r )
// we haven't done it before, so maybe we should. but
// wait - if it's an unqualified name, only ask when all
// the other alternatives are exhausted.
- if ( q == m->queries.size() && ( s.tqfind( '.' ) >= 0 ||
+ if ( q == m->queries.size() && ( s.find( '.' ) >= 0 ||
l->count() >= n.count()-1 ) ) {
TQDnsQuery * query = new TQDnsQuery;
query->started = now();
query->id = ++::id;
query->t = r->recordType();
query->l = s;
- query->dns->tqreplace( (void*)r, (void*)r );
+ query->dns->replace( (void*)r, (void*)r );
TQObject::connect( query, TQT_SIGNAL(timeout()),
TQDnsManager::manager(), TQT_SLOT(retransmit()) );
TQDnsManager::manager()->transmitQuery( query );
} else if ( q < m->queries.size() ) {
// if we've found an earlier query for the same
// domain/type, subscribe to its answer
- m->queries[q]->dns->tqreplace( (void*)r, (void*)r );
+ m->queries[q]->dns->replace( (void*)r, (void*)r );
}
}
}
@@ -4442,7 +4442,7 @@ void TQDns::setLabel( const TQHostAddress & address )
\value Mx Mail eXchanger names. Used for mail delivery.
- \value Srv SeRVer names. Generic record type for tqfinding
+ \value Srv SeRVer names. Generic record type for finding
servers. So far mostly unused.
\value Cname Canonical names. Maps from nicknames to the true
@@ -4653,7 +4653,7 @@ TQValueList<TQHostAddress> TQDns::addresses() const
/*!
Returns a list of mail servers if the record type is \c Mx. The
- class \c TQDns::MailServer tqcontains the following public variables:
+ class \c TQDns::MailServer contains the following public variables:
\list
\i TQString TQDns::MailServer::name
\i TQ_UINT16 TQDns::MailServer::priority
@@ -4709,7 +4709,7 @@ TQValueList<TQDns::MailServer> TQDns::mailServers() const
/*!
Returns a list of servers if the record type is \c Srv. The class
- \c TQDns::Server tqcontains the following public variables:
+ \c TQDns::Server contains the following public variables:
\list
\i TQString TQDns::Server::name
\i TQ_UINT16 TQDns::Server::priority
@@ -5056,7 +5056,7 @@ void TQDns::doResInit()
if ( !nameServer.isEmpty() ) {
first = 0;
do {
- last = nameServer.tqfind( separator, first );
+ last = nameServer.find( separator, first );
if ( last < 0 )
last = nameServer.length();
TQDns tmp( nameServer.mid( first, last-first ), TQDns::A );
@@ -5072,7 +5072,7 @@ void TQDns::doResInit()
searchList = searchList.simplifyWhiteSpace().lower();
first = 0;
do {
- last = searchList.tqfind( separator, first );
+ last = searchList.find( separator, first );
if ( last < 0 )
last = searchList.length();
domains->append( qstrdup( searchList.mid( first, last-first ) ) );
@@ -5194,7 +5194,7 @@ void TQDns::doResInit()
struct __res_state res;
res_ninit( &res );
int i;
// tqfind the name servers to use
for( i=0; i < MAXNS && i < res.nscount; i++ )
ns->append( new TQHostAddress( ntohl( res.nsaddr_list[i].sin_addr.s_addr ) ) );
# if defined(MAXDFLSRCH)
@@ -5210,7 +5210,7 @@ void TQDns::doResInit()
#else
qdns_res_init();
int i;
// tqfind the name servers to use
for( i=0; i < MAXNS && i < _res.nscount; i++ )
ns->append( new TQHostAddress( ntohl( _res.nsaddr_list[i].sin_addr.s_addr ) ) );
# if defined(MAXDFLSRCH)
@@ -5239,7 +5239,7 @@ void TQDns::doResInit()
TQFile hosts( TQString::tqfromLatin1( "/etc/hosts" ) );
if ( hosts.open( IO_ReadOnly ) ) {
// read the /etc/hosts file, creating long-life A and PTR RRs
// for the things we tqfind.
TQTextStream i( &hosts );
TQString line;
while( !i.atEnd() ) {
@@ -1241,7 +1241,7 @@ void TQDnsManager::transmitQuery( int i )
TQDns::doResInit();
if ( !theNs || theNs->isEmpty() ) {
- // we don't tqfind any name servers. We fake an NXDomain
+ // we don't find any name servers. We fake an NXDomain
// with a very short life time...
TQDnsAnswer answer( q );
@@ -2496,7 +2496,7 @@ void TQDns::doResInit()
res_ninit( &res );
int i;
- // tqfind the name servers to use
+ // find the name servers to use
for( i=0; i < MAXNS && i < res.nscount; i++ )
theNs->append( new TQHostAddress( ntohl( res.nsaddr_list[i].sin_addr.s_addr ) ) );
@@ -2512,7 +2512,7 @@ void TQDns::doResInit()
res_init();
int i;
- // tqfind the name servers to use
+ // find the name servers to use
for( i=0; i < MAXNS && i < _res.nscount; i++ )
theNs->append( new TQHostAddress( ntohl( _res.nsaddr_list[i].sin_addr.s_addr ) ) );
@@ -2541,7 +2541,7 @@ void TQDns::doResInit()
if ( hosts.open( QIODevice::ReadOnly ) ) {
// read the /etc/hosts file, creating long-life A and PTR RRs
- // for the things we tqfind.
+ // for the things we find.
QTextStream i( &hosts );
TQString line;
@@ -3848,7 +3848,7 @@ void TQDnsManager::transmitQuery( int i )
TQDns::doResInit();
if ( !ns || ns->isEmpty() ) {
- // we don't tqfind any name servers. We fake an NXDomain
+ // we don't find any name servers. We fake an NXDomain
// with a very short life time...
TQDnsAnswer answer( q );
@@ -5194,7 +5194,7 @@ void TQDns::doResInit()
res_ninit( &res );
int i;
- // tqfind the name servers to use
+ // find the name servers to use
for( i=0; i < MAXNS && i < res.nscount; i++ )
ns->append( new TQHostAddress( ntohl( res.nsaddr_list[i].sin_addr.s_addr ) ) );
@@ -5210,7 +5210,7 @@ void TQDns::doResInit()
qdns_res_init();
int i;
- // tqfind the name servers to use
+ // find the name servers to use
for( i=0; i < MAXNS && i < _res.nscount; i++ )
ns->append( new TQHostAddress( ntohl( _res.nsaddr_list[i].sin_addr.s_addr ) ) );
@@ -5239,7 +5239,7 @@ void TQDns::doResInit()
if ( hosts.open( IO_ReadOnly ) ) {
// read the /etc/hosts file, creating long-life A and PTR RRs
- // for the things we tqfind.
+ // for the things we find.
TQTextStream i( &hosts );
TQString line;
diff --git a/tqtinterface/qt4/src/network/tqhostaddress.cpp b/tqtinterface/qt4/src/network/tqhostaddress.cpp
index f6720e4..5a4e5cf 100644
--- a/tqtinterface/qt4/src/network/tqhostaddress.cpp
+++ b/tqtinterface/qt4/src/network/tqhostaddress.cpp
@@ -96,7 +96,7 @@ TQHostAddressPrivate::TQHostAddressPrivate(const TQ_IPV6ADDR &a_) : a(0), isIp4(
\ingroup io
\module network
- This class tqcontains an IP address in a platform and protocol
+ This class contains an IP address in a platform and protocol
independent manner. It stores both IPv4 and IPv6 addresses in a
way that you can easily access on any platform.
@@ -378,7 +378,7 @@ bool TQHostAddress::isIPv6Address() const
\code
TQ_IPV6ADDR addr = hostAddr.ip6Addr();
// addr.c[] tqcontains 16 unsigned characters
for (int i = 0; i < 16; ++i) {
// process addr.c[i]
@@ -378,7 +378,7 @@ bool TQHostAddress::isIPv6Address() const
\code
TQ_IPV6ADDR addr = hostAddr.ip6Addr();
- // addr.c[] tqcontains 16 unsigned characters
+ // addr.c[] contains 16 unsigned characters
for (int i = 0; i < 16; ++i) {
// process addr.c[i]
diff --git a/tqtinterface/qt4/src/network/tqsocket.cpp b/tqtinterface/qt4/src/network/tqsocket.cpp
index 52d95cc..c894f3e 100644
--- a/tqtinterface/qt4/src/network/tqsocket.cpp
+++ b/tqtinterface/qt4/src/network/tqsocket.cpp
@@ -248,7 +248,7 @@ void TQSocketPrivate::setSocketDevice( TQSocket *q, TQSocketDevice *tqdevice )
Most network protocols are either packet-oriented or
line-oriented. canReadLine() indicates whether a connection
- tqcontains an entire unread line or not, and bytesAvailable()
+ contains an entire unread line or not, and bytesAvailable()
returns the number of bytes available for reading.
The Q_SIGNALS error(), connected(), readyRead() and
@@ -325,7 +325,7 @@ qint64 TQSocket::readData( char *data, qint64 maxlen )
// readyRead() signal since this might cause a bad recursive behavior.
// We can test for this condition by looking at the
// sn_read_alreadyCalled flag.
- if ( d->rsn && TQSocketPrivate::sn_read_alreadyCalled.tqfindRef(this) == -1 )
+ if ( d->rsn && TQSocketPrivate::sn_read_alreadyCalled.findRef(this) == -1 )
d->rsn->setEnabled( true );
return maxlen;
}
@@ -593,7 +593,7 @@ void TQSocket::tryConnecting()
return;
}
// we've found something. press on with that. if we later tqfind
// more, fine.
emit hostFound();
d->state = Connecting;
@@ -777,7 +777,7 @@ bool TQSocket::open( int m )
If the output buffer is empty, the state is set to \c
TQSocket::Idle and the connection is terminated immediately. If the
- output buffer still tqcontains data to be written, TQSocket goes into
+ output buffer still contains data to be written, TQSocket goes into
the \c TQSocket::Closing state and the rest of the data will be
written. When all of the outgoing data have been written, the
state is set to \c TQSocket::Idle and the connection is terminated.
@@ -982,7 +982,7 @@ bool TQSocket::at( Offset index )
// readyRead() signal since this might cause a bad recursive behavior.
// We can test for this condition by looking at the
// sn_read_alreadyCalled flag.
- if ( d->rsn && TQSocketPrivate::sn_read_alreadyCalled.tqfindRef(this) == -1 )
+ if ( d->rsn && TQSocketPrivate::sn_read_alreadyCalled.findRef(this) == -1 )
d->rsn->setEnabled( TRUE );
return TRUE;
}
@@ -1038,7 +1038,7 @@ TQ_ULONG TQSocket::bytesAvailable() const
If \a timeout is non-null and no error occurred (i.e. it does not
return -1): this function sets \a *timeout to TRUE, if the reason
for returning was that the timeout was reached; otherwise it sets
- \a *timeout to FALSE. This is useful to tqfind out if the peer
+ \a *timeout to FALSE. This is useful to find out if the peer
closed the connection.
\warning This is a blocking call and should be avoided in event
@@ -1126,7 +1126,7 @@ TQ_LONG TQSocket::readBlock( char *data, TQ_ULONG maxlen )
// readyRead() signal since this might cause a bad recursive behavior.
// We can test for this condition by looking at the
// sn_read_alreadyCalled flag.
- if ( d->rsn && TQSocketPrivate::sn_read_alreadyCalled.tqfindRef(this) == -1 )
+ if ( d->rsn && TQSocketPrivate::sn_read_alreadyCalled.findRef(this) == -1 )
d->rsn->setEnabled( TRUE );
return maxlen;
}
@@ -1209,7 +1209,7 @@ int TQSocket::getch()
// readyRead() signal since this might cause a bad recursive behavior.
// We can test for this condition by looking at the
// sn_read_alreadyCalled flag.
- if ( d->rsn && TQSocketPrivate::sn_read_alreadyCalled.tqfindRef(this) == -1 )
+ if ( d->rsn && TQSocketPrivate::sn_read_alreadyCalled.findRef(this) == -1 )
d->rsn->setEnabled( TRUE );
return c;
}
@@ -1331,7 +1331,7 @@ void TQSocket::sn_read( bool force )
// Use TQSocketPrivate::sn_read_alreadyCalled to avoid recursive calls of
// sn_read() (and as a result avoid emitting the readyRead() signal in a
// slot for readyRead(), if you use bytesAvailable()).
- if ( !force && TQSocketPrivate::sn_read_alreadyCalled.tqfindRef(this) != -1 )
+ if ( !force && TQSocketPrivate::sn_read_alreadyCalled.findRef(this) != -1 )
return;
TQSocketPrivate::sn_read_alreadyCalled.append( this );
@@ -593,7 +593,7 @@ void TQSocket::tryConnecting()
return;
}
- // we've found something. press on with that. if we later tqfind
+ // we've found something. press on with that. if we later find
// more, fine.
emit hostFound();